Department of the Treasury **Internal Revenue Service**

# Publication 1244

(Rev. July 1996)

# Employee’s Daily Record of Tips

# and Report to Employer

**This publication contains:** **Form 4070A,  Employee’s Daily Record of** Tips **Form 4070,  Employee’s Report of Tips to** Employer

For the period

beginning, 19 and

ending, 19

Name and address of employee

**Publication 1244 (Rev. 7-96)** Cat. No. 44472W

**Instructions** You must keep sufficient proof to show the amount of your tip income for the year. A daily record of your tip income is considered sufficient proof. Keep a daily record for each workday showing the amount of cash and credit card tips received directly from customers or other employees. Also keep a record of the amount of tips, if any, you paid to other employees through tip sharing, tip pooling or other arrangements, and the names of employees to whom you paid tips. Show the date that each entry is made. This date should be on or near the date you received the tip income. You may use  Form 4070A , Employee’s Daily Record of Tips, or any other daily record to record your tips. **Reporting Tips to Your Employer.— If you** receive tips that total $20 or more for any month while working for one employer, you must report the tips to your employer. Tips include cash left by customers, tips customers add to credit card charges, and tips you receive from other employees. You must report your tips for any one month by the 10th day of the next month. If the 10th day falls on a Saturday, Sunday, or legal holiday, you may give the report to your employer on the next business day that is not a Saturday, Sunday, or legal holiday. You must report tips that total $20 or more every month regardless of your total wages and tips for the year. You may use  Form 4070, Employee’s Report of Tips to Employer, to report your tips to your employer. See the instructions on the back of Form 4070. You must include all tips, including tips not reported to your employer, as wages on your income tax return. You may use the last page of this publication to total your tips for the year. Your employer must withhold income, social security, and Medicare (or railroad retirement) taxes on tips you report. Your employer usually deducts the withholding due on tips from your regular wages.

*(continued on inside of back cover)*

Form **4070A** Employee’s Daily Record of Tips (Rev. July 1996) **This is a voluntary form provided for your convenience.** OMB No. 1545-0065 Department of the Treasury **See instructions for records you must keep.** Internal Revenue Service Employee’s name and address Employer’s name Month and year

Establishment name (if different)

Date Date **a. Tips received**

**b. Credit card tips c. Tips paid out to d. Names of employees to whom you**
tips of directly from customers received other employees paid tips rec’d. entry and other employees 1 2 3 4 5 **Subtotals** **For Paperwork Reduction Act Notice, see Instructions on the back of Form 4070. Page 1**

7 8 9 10 11 12 13 14 15 **Subtotals**

**Page 2**

17 18 19 20 21 22 23 24 25 **Subtotals**

**Page 3**

27 28 29 30 31 **Subtotals** **from pages** **1, 2, and 3** **Totals**

**1.** Report total cash tips (col.  a) on Form 4070, line  1.
**2.** Report total credit card tips (col.  b) on Form 4070, line  2.
**3.** Report total tips paid out (col.  c) on Form 4070, line  3. **Page 4**

Form Employee’s Report (Rev. July 1996)

## of Tips to EmployerOMB No. 1545-0065

Department of the Treasury Internal Revenue Service' **For Paperwork Reduction Act Notice, see back of form.** Employee’s name and address **Social security number**

Employer’s name and address (include establishment name, if different) **1** Cash tips received

**2** Credit card tips received

**3** Tips paid out

Month or shorter period in which tips were received **4** Net tips (lines  1 + 2 - 3 ) from, 19, to, 19 Signature Date

**Paperwork Reduction Act Notice.— We ask for the** information on these forms to carry out the Internal Revenue laws of the United States. You are required to give us the information. We need it to ensure that you are complying with these laws and to allow us to figure and collect the right amount of tax. You are not required to provide the information requested on a form that is subject to the Paperwork Reduction Act unless the form displays a valid OMB control number. Books or records relating to a form or its instructions must be retained as long as their contents may become material in the administration of any Internal Revenue law. Generally, tax returns and return information are confidential, as required by Code section 6103. The time needed to complete Forms 4070 and 4070A will vary depending on individual circumstances. The estimated average times are:  Recordkeeping—Form 4070, 7 min.; Form 4070A, 3 hr. and 23 min.; **Learning** **about the law —each form, 2 min.;  Preparing Form 4070,** 13 min.; Form 4070A, 55 min.; and  Copying and **providing Form 4070, 10 min.; Form 4070A, 14 min.** If you have comments concerning the accuracy of these time estimates or suggestions for making these

forms simpler, we would be happy to hear from you. You can write to the Tax Forms Committee, Western Area Distribution Center, Rancho Cordova, CA 95743-0001. **Purpose.—Use this form to report tips you receive to** your employer. This includes cash tips, tips you receive from other employees, and credit card tips. You must report tips every month regardless of your total wages and tips for the year. However, you do not have to report tips to your employer for any month you received less than $20 in tips while working for that employer. Report tips by the 10th day of the month following the month that you receive them. If the 10th day is a Saturday, Sunday, or legal holiday, report tips by the next day that is not a Saturday, Sunday, or legal holiday. See Pub. 531, Reporting Tip Income, for more information. You can get additional copies of  Pub. 1244, Employee’s Daily Record of Tips and Report to Employer, which contains both Forms 4070A and 4070, by calling 1-800-TAX-FORM (1-800-829-3676).

**Instructions (continued)**

**Unreported Tips.—If you received tips of $20 or** more for any month while working for one employer but did not report them to your employer, you must figure and pay social security and Medicare taxes on the unreported tips when you file your tax return. If you have unreported tips, you  must use Form 1040 and  Form 4137, Social Security and Medicare Tax on Unreported Tip Income, to report them. You may  not use Form 1040A or 1040EZ. Employees subject to the Railroad Retirement Tax Act  cannot use Form 4137 to pay railroad retirement tax on unreported tips. To get railroad retirement credit, you must report tips to your employer. If you do not report tips to your employer as required, you may be charged a penalty of 50% of the social security and Medicare taxes (or railroad retirement tax) due on the unreported tips unless there was reasonable cause for not reporting them. **Additional Information.—Get Pub. 531,  Reporting** Tip Income, and Form 4137 for more information on tips. If you are an employee of certain large food or beverage establishments, see Pub. 531 for tip allocation rules. **Recordkeeping.—If you do not keep a daily** record of tips, you must keep other reliable proof of the tip income you received. This proof includes copies of restaurant bills and credit card charges that show amounts customers added as tips. Keep your tip income records for as long as the information on them may be needed in the administration of any Internal Revenue law.

**Instructions (continued)**

Use this space to total your tips for the year

